From 1003d7be0dcde8f4341b3e3970a6b37a7f50b44a Mon Sep 17 00:00:00 2001
From: "Roberto A. Foglietta" <roberto.foglietta@gmail.com>
Date: Sat, 24 Dec 2022 16:38:47 +0100
Subject: [PATCH] scripts/ci_build.sh virtualenv uses mktemp to avoid conflicts

Previous user or concurrent users may use scripts/ci_build.sh and in
particular root user creates a temporary directory that is not removable by
common users. Using a combination of mktemp and trap on EXIT will solve
all of these problems.

This patch applies on the top of the current one:

 * scripts/ci_build.sh installs required commands

Signed-off-by: Roberto A. Foglietta <roberto.foglietta@gmail.com>
---
 scripts/ci_build.sh | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/scripts/ci_build.sh b/scripts/ci_build.sh
index e897942..1d638e9 100755
--- a/scripts/ci_build.sh
+++ b/scripts/ci_build.sh
@@ -26,9 +26,10 @@ done
 
 # install avocado in virtualenv in case it is not there already
 if ! command -v avocado > /dev/null; then
-    rm -rf /tmp/avocado_venv
-    virtualenv --python python3 /tmp/avocado_venv
-    source /tmp/avocado_venv/bin/activate
+    tmpdir=$(mktemp -p "$TMPDIR" -d avocado_venv.XXXX)
+    trap "rm -rf $tmpdir" EXIT
+    virtualenv --python python3 $tmpdir
+    source $tmpdir/bin/activate
     pip install avocado-framework==96.0
 fi
 
-- 
2.34.1

